==> mx-packageinstaller-pkglist_18.12.06.tar.xz: mx-packageinstaller-pkglist/romanian_firefox.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Romanian_Firfox
</name>

<description>
   <am>Romanian localisation of Firefox</am>
   <ca>Localització de Firefox en Romanès</ca>
   <cs>Romanian localisation of Firefox</cs>
   <da>Rumænsk oversættelse af Firefox</da>
   <de>Rumänische Lokalisierung von Firefox</de>
   <el>Ρουμανικός εντοπισμός του Firefox</el>
   <en>Romanian localisation of Firefox</en>
   <es>Romanian localisation of Firefox</es>
   <fi>Romanian localisation of Firefox</fi>
   <fr>Localisation roumaine pour Firefox</fr>
   <hi>Romanian localisation of Firefox</hi>
   <hr>Romanian localisation of Firefox</hr>
   <hu>Romanian localisation of Firefox</hu>
   <is>Romanian localisation of Firefox</is>
   <it>Localizzazione rumena di Firefox</it>
   <ja>Romanian localisation of Firefox</ja>
   <kk>Romanian localisation of Firefox</kk>
   <lt>Romanian localisation of Firefox</lt>
   <nl>Roemeense lokalisatie van Firefox</nl>
   <pl>Romanian localisation of Firefox</pl>
   <pt_BR>Romeno Localização para Firefox</pt_BR>
   <pt>Romeno Localização para Firefox</pt>
   <ro>Romanian localisation of Firefox</ro>
   <ru>Romanian localisation of Firefox</ru>
   <sk>Romanian localisation of Firefox</sk>
   <sq>Romanian localisation of Firefox</sq>
   <sv>Rumänsk lokalisering av Firefox</sv>
   <tr>Romanian localisation of Firefox</tr>
   <uk>Romanian localisation of Firefox</uk>
   <zh_TW>Romanian localisation of Firefox</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
firefox-l10n-xpi-ro
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
firefox-l10n-xpi-ro
</uninstall_package_names>
</app>

==> mx-packageinstaller-pkglist_19.01.03.tar.xz: mx-packageinstaller-pkglist/romanian_firefox.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Romanian_Firfox
</name>

<description>
   <am>Romanian localisation of Firefox</am>
   <ar>Romanian localisation of Firefox</ar>
   <bg>Romanian localisation of Firefox</bg>
   <ca>Localització de Firefox en Romanès</ca>
   <cs>Romanian localisation of Firefox</cs>
   <da>Rumænsk oversættelse af Firefox</da>
   <de>Rumänische Lokalisierung von Firefox</de>
   <el>Ρουμανικός εντοπισμός του Firefox</el>
   <en>Romanian localisation of Firefox</en>
   <es>Romanian localisation of Firefox</es>
   <et>Romanian localisation of Firefox</et>
   <eu>Romanian localisation of Firefox</eu>
   <fa>Romanian localisation of Firefox</fa>
   <fi>Romanian localisation of Firefox</fi>
   <fr>Localisation roumaine pour Firefox</fr>
   <he_IL>Romanian localisation of Firefox</he_IL>
   <hi>Romanian localisation of Firefox</hi>
   <hr>Romanian localisation of Firefox</hr>
   <hu>Romanian localisation of Firefox</hu>
   <id>Romanian localisation of Firefox</id>
   <is>Romanian localisation of Firefox</is>
   <it>Localizzazione rumena di Firefox</it>
   <ja_JP>Romanian localisation of Firefox</ja_JP>
   <ja>Romanian localisation of Firefox</ja>
   <kk>Romanian localisation of Firefox</kk>
   <ko>Romanian localisation of Firefox</ko>
   <lt>Romanian localisation of Firefox</lt>
   <mk>Romanian localisation of Firefox</mk>
   <nb>Romanian localisation of Firefox</nb>
   <nl>Roemeense lokalisatie van Firefox</nl>
   <pl>Romanian localisation of Firefox</pl>
   <pt_BR>Romeno Localização para Firefox</pt_BR>
   <pt>Romeno Localização para Firefox</pt>
   <ro>Romanian localisation of Firefox</ro>
   <ru>Romanian localisation of Firefox</ru>
   <sk>Romanian localisation of Firefox</sk>
   <sl>Romanian localisation of Firefox</sl>
   <sq>Romanian localisation of Firefox</sq>
   <sr>Romanian localisation of Firefox</sr>
   <sv>Rumänsk lokalisering av Firefox</sv>
   <tr>Romanian localisation of Firefox</tr>
   <uk>Romanian локалізація Firefox</uk>
   <zh_CN>Romanian localisation of Firefox</zh_CN>
   <zh_TW>Romanian localisation of Firefox</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
firefox-l10n-xpi-ro
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
firefox-l10n-xpi-ro
</uninstall_package_names>
</app>
